/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ATBTimer.h"

// Sigbattle includes
#include "ATBArena.h"

// Qt includes
#include <QtCore/QtAlgorithms>
#include <QtCore/QtConcurrentFilter>
#include <QtCore/QtConcurrentMap>
#include <QtCore/QFuture>
#include <QtCore/QMultiMap>
#include <QtCore/QTimer>

// STL includes
#include <functional>

bool Sigbattle::compareTimers(TeamMember* const & member1, TeamMember* const & member2)
{
    return member1->timer() < member2->timer();
}

Sigbattle::ATBTimer::ATBTimer(ATBArena* arena, ActionQueue& actions) :
        QThread(arena),
        m_arena(arena),
        m_actions(actions),
        m_timer(new QTimer(this))
{
    connect(m_timer, SIGNAL(timeout()), this, SLOT(update()));
}

void Sigbattle::ATBTimer::update()
{
    const QList<TeamMember*> active = m_arena->active();
    QtConcurrent::blockingMap(active, std::bind1st(std::mem_fun(&Sigbattle::ATBTimer::increaseMeter), this));
    // TODO: adjust max time if needed
    QList<TeamMember*> overflow = QtConcurrent::blockingFiltered(active, std::bind1st(std::mem_fun(&Sigbattle::ATBTimer::isOverflowed), this));
    qSort(overflow.begin(), overflow.end(), compareTimers);
    foreach(TeamMember* teamMember, overflow)
        m_actions.enqueue(requestDecision(teamMember));
}

void Sigbattle::ATBTimer::run()
{
    m_timer->start(50);
    exec();
}

void Sigbattle::ATBTimer::increaseMeter(TeamMember* teamMember)
{
    // TODO: tweak this(?)
    teamMember->advanceTimer(teamMember->statValue(Sigmod::ST_Speed) / 10);
}

bool Sigbattle::ATBTimer::isOverflowed(const TeamMember* teamMember) const
{
    return m_threshold < teamMember->timer();
}
