/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Ability.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

Sigmod::Ability::Ability(const Ability& ability) :
        Object(ability.parent(), ability.id())
{
    *this = ability;
}

Sigmod::Ability::Ability(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_priority(0),
        m_description(""),
        m_battleScript("", ""),
        m_worldScript("", ""),
        m_priorityScript("", "")
{
}

Sigmod::Ability::Ability(const Ability& ability, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = ability;
}

Sigmod::Ability::Ability(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Ability::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::Ability::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(priority);
    LOAD(description);
    LOAD(battleScript);
    LOAD(worldScript);
    LOAD(priorityScript);
}

QDomElement Sigmod::Ability::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(priority);
    SAVE(description);
    SAVE(battleScript);
    SAVE(worldScript);
    SAVE(priorityScript);
    return xml;
}

void Sigmod::Ability::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Ability::setPriority(const int priority)
{
    CHECK(priority);
}

void Sigmod::Ability::setDescription(const QString& description)
{
    CHECK(description);
}

void Sigmod::Ability::setBattleScript(const Script& battleScript)
{
    CHECK(battleScript);
}

void Sigmod::Ability::setWorldScript(const Script& worldScript)
{
    CHECK(worldScript);
}

void Sigmod::Ability::setPriorityScript(const Script& priorityScript)
{
    CHECK(priorityScript);
}

QString Sigmod::Ability::name() const
{
    return m_name;
}

int Sigmod::Ability::priority() const
{
    return m_priority;
}

QString Sigmod::Ability::description() const
{
    return m_description;
}

Sigmod::Script Sigmod::Ability::battleScript() const
{
    return m_battleScript;
}

Sigmod::Script Sigmod::Ability::worldScript() const
{
    return m_worldScript;
}

Sigmod::Script Sigmod::Ability::priorityScript() const
{
    return m_priorityScript;
}

Sigmod::Ability& Sigmod::Ability::operator=(const Ability& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(priority);
    COPY(description);
    COPY(battleScript);
    COPY(worldScript);
    COPY(priorityScript);
    return *this;
}
