/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_ABILITY
#define SIGMOD_ABILITY

// Sigmod includes
#include "Object.h"
#include "Script.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Ability : public Object
{
    Q_OBJECT
    
    public:
        Ability(const Ability& ability);
        Ability(const Sigmod* parent, const int id);
        Ability(const Ability& ability, const Sigmod* parent, const int id);
        Ability(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setPriority(const int priority);
        void setDescription(const QString& description);
        void setBattleScript(const Script& battleScript);
        void setWorldScript(const Script& worldScript);
        void setPriorityScript(const Script& priorityScript);
        
        QString name() const;
        int priority() const;
        QString description() const;
        Script battleScript() const;
        Script worldScript() const;
        Script priorityScript() const;
        
        Ability& operator=(const Ability& rhs);
    private:
        QString m_name;
        int m_priority;
        QString m_description;
        Script m_battleScript;
        Script m_worldScript;
        Script m_priorityScript;
};
}

#endif
