/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_COINLIST
#define SIGMOD_COINLIST

// Sigmod includes
#include "Object.h"
#include "Script.h"

// Qt includes
#include <QtCore/QList>

namespace Sigmod
{
// Forward declarations
class CoinListObject;
class Sigmod;

class SIGMOD_EXPORT CoinList : public Object
{
    Q_OBJECT
    
    public:
        CoinList(const CoinList& coinList);
        CoinList(const Sigmod* parent, const int id);
        CoinList(const CoinList& coinList, const Sigmod* parent, const int id);
        CoinList(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        ~CoinList();
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setScript(const Script& script);
        
        QString name() const;
        Script script() const;
        
        const CoinListObject* object(const int index) const;
        CoinListObject* object(const int index);
        const CoinListObject* objectById(const int id) const;
        CoinListObject* objectById(const int id);
        int objectIndex(const int id) const;
        int objectCount() const;
        CoinListObject* newObject();
        CoinListObject* newObject(const QDomElement& xml);
        CoinListObject* newObject(const CoinListObject& object);
        void deleteObject(const int index);
        void deleteObjectById(const int id);
        
        CoinList& operator=(const CoinList& rhs);
    private:
        int objectId() const;
        CoinListObject* newObject(CoinListObject* object);
        
        void clear();
        
        QString m_name;
        Script m_script;
        QList<CoinListObject*> m_objects;
};
}

#endif
