/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_FRACTION
#define SIGMOD_FRACTION

// Sigmod includes
#include "Global.h"

// Qt includes
#include <QtCore/QMetaType>

namespace Sigmod
{
class SIGMOD_EXPORT Fraction
{
    public:
        explicit Fraction(const int numerator = 1, const int denominator = 1);
        Fraction(const Fraction& fraction);
        
        void set(const int numerator, const int denominator);
        void setNumerator(const int numerator);
        void setDenominator(const int denominator);
        
        int numerator() const;
        int denominator() const;
        
        void reduce();
        bool poll() const;
        static bool poll(const int numerator, const int demoninator);
        
        Fraction& operator=(const Fraction& rhs);
        operator double() const;
        Fraction operator+(const Fraction& rhs) const;
        Fraction operator-(const Fraction& rhs) const;
        Fraction operator*(const Fraction& rhs) const;
        Fraction operator/(const Fraction& rhs) const;
        Fraction operator%(const Fraction& rhs) const;
        Fraction& operator+=(const Fraction& rhs);
        Fraction& operator-=(const Fraction& rhs);
        Fraction& operator*=(const Fraction& rhs);
        Fraction& operator/=(const Fraction& rhs);
        Fraction& operator%=(const Fraction& rhs);
        bool operator==(const Fraction& rhs) const;
        bool operator!=(const Fraction& rhs) const;
    protected:
        void normalize();
    private:
        int m_numerator;
        int m_denominator;
};
}
Q_DECLARE_METATYPE(Sigmod::Fraction)

#endif
