/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_ITEM
#define SIGMOD_ITEM

// Sigmod includes
#include "Object.h"
#include "Script.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Item : public Object
{
    Q_OBJECT
    
    public:
        Item(const Item& item);
        Item(const Sigmod* parent, const int id);
        Item(const Item& item, const Sigmod* parent, const int id);
        Item(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        ~Item();
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setSellable(const bool sellable);
        void setType(const int type);
        void setPrice(const int price);
        void setDescription(const QString& description);
        void setScript(const Script& script);
        
        QString name() const;
        bool sellable() const;
        int type() const;
        int price() const;
        QString description() const;
        Script script() const;
        
        Item& operator=(const Item& rhs);
    private:
        QString m_name;
        bool m_sellable;
        int m_type;
        int m_price;
        QString m_description;
        Script m_script;
};
}

#endif
