/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ItemType.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

QStringList Sigmod::ItemType::CountStr = QStringList() << "Distinct" << "Total";

Sigmod::ItemType::ItemType(const ItemType& itemType) :
        Object(itemType.parent(), itemType.id())
{
    *this = itemType;
}

Sigmod::ItemType::ItemType(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_computer(0),
        m_player(1),
        m_count(Distinct)
{
}

Sigmod::ItemType::ItemType(const ItemType& itemType, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = itemType;
}

Sigmod::ItemType::ItemType(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::ItemType::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST(setPlayer, player);
    TEST_END();
}

void Sigmod::ItemType::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(computer);
    LOAD(player);
    LOAD(count);
}

QDomElement Sigmod::ItemType::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(computer);
    SAVE(player);
    SAVE(count);
    return xml;
}

void Sigmod::ItemType::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::ItemType::setComputer(const int computer)
{
    CHECK(computer);
}

void Sigmod::ItemType::setPlayer(const int player)
{
    if (!player)
        emit(error(bounds("player")));
    else
        CHECK(player);
}

void Sigmod::ItemType::setCount(const Count count)
{
    CHECK(count);
}

QString Sigmod::ItemType::name() const
{
    return m_name;
}

int Sigmod::ItemType::computer() const
{
    return m_computer;
}

int Sigmod::ItemType::player() const
{
    return m_player;
}

Sigmod::ItemType::Count Sigmod::ItemType::count() const
{
    return m_count;
}

Sigmod::ItemType& Sigmod::ItemType::operator=(const ItemType& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(computer);
    COPY(player);
    COPY(count);
    return *this;
}
