/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_MAPEFFECT
#define SIGMOD_MAPEFFECT

// Sigmod includes
#include "Object.h"
#include "Script.h"

// Qt includes
#include <QtCore/QPoint>

namespace Sigmod
{
// Forward declarations
class Map;

class SIGMOD_EXPORT MapEffect : public Object
{
    Q_OBJECT
    
    public:
        MapEffect(const MapEffect& effect);
        MapEffect(const Map* parent, const int id);
        MapEffect(const MapEffect& effect, const Map* parent, const int id);
        MapEffect(const QDomElement& xml, const Map* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setCoordinate(const QPoint& coordinate);
        void setSkin(const int skin);
        void setIsGhost(const bool isGhost);
        void setScript(const Script& script);
        
        QString name() const;
        QPoint coordinate() const;
        int skin() const;
        bool isGhost() const;
        Script script() const;
        
        MapEffect& operator=(const MapEffect& rhs);
    private:
        QString m_name;
        QPoint m_coordinate;
        int m_skin;
        bool m_isGhost;
        Script m_script;
};
}

#endif
