/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_MAPTRAINERTEAMMEMBER
#define SIGMOD_MAPTRAINERTEAMMEMBER

// Sigmod includes
#include "Object.h"

// Qt includes
#include <QtCore/QList>

namespace Sigmod
{
// Forward dclarations
class MapTrainer;

class SIGMOD_EXPORT MapTrainerTeamMember : public Object
{
    Q_OBJECT
    
    public:
        MapTrainerTeamMember(const MapTrainerTeamMember& teamMember);
        MapTrainerTeamMember(const MapTrainer* parent, const int id);
        MapTrainerTeamMember(const MapTrainerTeamMember& teamMember, const MapTrainer* parent, const int id);
        MapTrainerTeamMember(const QDomElement& xml, const MapTrainer* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setSpecies(const int species);
        void setLevel(const int level);
        void setAbility(const int ability, const bool state);
        void setItem(const int item, const bool state);
        void setMove(const int move, const bool state);
        void setNature(const int nature, const bool state);
        
        int species() const;
        int level() const;
        bool ability(const int ability) const;
        QList<int> abilities() const;
        bool item(const int item) const;
        QList<int> items() const;
        bool move(const int move) const;
        QList<int> moves() const;
        bool nature(const int nature) const;
        QList<int> natures() const;

        MapTrainerTeamMember& operator=(const MapTrainerTeamMember& p);
    private:
        int m_species;
        int m_level;
        QList<int> m_ability;
        QList<int> m_item;
        QList<int> m_move;
        QList<int> m_nature;
};
}

#endif
