/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_MAPWARP
#define SIGMOD_MAPWARP

// Sigmod includes
#include "Object.h"
#include "Script.h"

// Qt includes
#include <QtCore/QPoint>

namespace Sigmod
{
// Forward declarations
class Map;

class SIGMOD_EXPORT MapWarp : public Object
{
    Q_OBJECT
    Q_ENUMS(Type)
    
    public:
        enum Type
        {
            Door = 0,
            Warp = 1,
            Hole = 2,
            Boundary = 3
        };
        static const QStringList TypeStr;
        
        MapWarp(const MapWarp& warp);
        MapWarp(const Map* parent, const int id);
        MapWarp(const MapWarp& warp, const Map* parent, const int id);
        MapWarp(const QDomElement& xml, const Map* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setCoordinate(const QPoint& coordinate);
        void setType(const Type type);
        void setToMap(const int toMap);
        void setToWarp(const int toWarp);
        void setScript(const Script& script);
        
        QString name() const;
        QPoint coordinate() const;
        Type type() const;
        int toMap() const;
        int toWarp() const;
        Script script() const;
        
        MapWarp& operator=(const MapWarp& rhs);
    private:
        QString m_name;
        QPoint m_coordinate;
        Type m_type;
        int m_toMap;
        int m_toWarp;
        Script m_script;
};
}
Q_DECLARE_METATYPE(Sigmod::MapWarp::Type)

#endif
