/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListEncounter.h"

// Sigmod includes
#include "Macros.h"
#include "MapWildList.h"
#include "Rules.h"
#include "Sigmod.h"
#include "Species.h"

Sigmod::MapWildListEncounter::MapWildListEncounter(const MapWildListEncounter& encounter) :
        Object(encounter.parent(), encounter.id())
{
    *this = encounter;
}

Sigmod::MapWildListEncounter::MapWildListEncounter(const MapWildList* parent, const int id) :
        Object(parent, id),
        m_species(INT_MAX),
        m_level(1),
        m_weight(1)
{
}

Sigmod::MapWildListEncounter::MapWildListEncounter(const MapWildListEncounter& encounter, const MapWildList* parent, const int id) :
        Object(parent, id)
{
    *this = encounter;
}

Sigmod::MapWildListEncounter::MapWildListEncounter(const QDomElement& xml, const MapWildList* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::MapWildListEncounter::validate()
{
    TEST_BEGIN();
    TEST(setSpecies, species);
    TEST(setLevel, level);
    TEST(setWeight, weight);
    TEST_END();
}

void Sigmod::MapWildListEncounter::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(species);
    LOAD(level);
    LOAD(weight);
}

QDomElement Sigmod::MapWildListEncounter::save() const
{
    SAVE_CREATE();
    SAVE(species);
    SAVE(level);
    SAVE(weight);
    return xml;
}

void Sigmod::MapWildListEncounter::setSpecies(const int species)
{
    if (qobject_cast<const Sigmod*>(sigmod())->speciesIndex(species) == INT_MAX)
        emit(error(bounds("species")));
    else
        CHECK(species);
}

void Sigmod::MapWildListEncounter::setLevel(const int level)
{
    if (!level || (qobject_cast<const Sigmod*>(sigmod())->rules()->maxLevel() <= level))
        emit(error(bounds("level")));
    else
        CHECK(level);
}

void Sigmod::MapWildListEncounter::setWeight(const int weight)
{
    if (!weight)
        emit(error(bounds("weight")));
    else
        CHECK(weight);
}

int Sigmod::MapWildListEncounter::species() const
{
    return m_species;
}

int Sigmod::MapWildListEncounter::level() const
{
    return m_level;
}

int Sigmod::MapWildListEncounter::weight() const
{
    return m_weight;
}

Sigmod::MapWildListEncounter& Sigmod::MapWildListEncounter::operator=(const MapWildListEncounter& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(species);
    COPY(level);
    COPY(weight);
    return *this;
}
