/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_MOVE
#define SIGMOD_MOVE

// Sigmod includes
#include "Fraction.h"
#include "Object.h"
#include "Script.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Move : public Object
{
    Q_OBJECT
    
    public:
        Move(const Move& move);
        Move(const Sigmod* parent, const int id);
        Move(const Move& move, const Sigmod* parent, const int id);
        Move(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        ~Move();
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setAccuracy(const Fraction& accuracy);
        void setPower(const int power);
        void setType(const int type);
        void setSpecial(const bool special);
        void setPowerPoints(const int powerPoints);
        void setPriority(const int priority);
        void setDescription(const QString& description);
        void setBattleScript(const Script& battleScript);
        void setWorldScript(const Script& worldScript);
        void setPriorityScript(const Script& priorityScript);
        
        QString name() const;
        Fraction accuracy() const;
        int power() const;
        int type() const;
        bool special() const;
        int powerPoints() const;
        int priority() const;
        QString description() const;
        Script battleScript() const;
        Script worldScript() const;
        Script priorityScript() const;
        
        Move& operator=(const Move& rhs);
    private:
        QString m_name;
        Fraction m_accuracy;
        int m_power;
        int m_type;
        bool m_special;
        int m_powerPoints;
        int m_priority;
        QString m_description;
        Script m_battleScript;
        Script m_worldScript;
        Script m_priorityScript;
};
}

#endif
