/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_NATURE
#define SIGMOD_NATURE

// Sigmod includes
#include "Fraction.h"
#include "Object.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Nature : public Object
{
    Q_OBJECT
    
    public:
        Nature(const Nature& nature);
        Nature(const Sigmod* parent, const int id);
        Nature(const Nature& nature, const Sigmod* parent, const int id);
        Nature(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setStat(const Stat stat, const Fraction& multiplier);
        void setWeight(const int weight);
        
        QString name() const;
        Fraction stat(const Stat stat) const;
        int weight() const;
        
        Nature& operator=(const Nature& rhs);
    private:
        void setStat(const Fraction& multiplier);
        
        QString m_name;
        QVarLengthArray<Fraction, ST_End_GSC - ST_No_HP_Start> m_stat;
        int m_weight;
};
}

#endif
