/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Object.h"

// Sigmod includes
#include "Macros.h"

Sigmod::Object::Object(const Object& object) :
        QObject(NULL),
        m_id(object.id()),
        m_parent(object.parent())
{
}

Sigmod::Object::Object(const Object* parent, const int id) :
        QObject(NULL),
        m_id(id),
        m_parent(parent)
{
}

const Sigmod::Object* Sigmod::Object::parent() const
{
    return m_parent;
}

const Sigmod::Object* Sigmod::Object::sigmod() const
{
    if (m_parent)
        return m_parent->sigmod();
    return this;
}

int Sigmod::Object::id() const
{
    return m_id;
}

void Sigmod::Object::setId(const int id)
{
    CHECK(id);
}

QString Sigmod::Object::className() const
{
    return QString(metaObject()->className()).section(':', -1);
}

QDomDocument Sigmod::Object::xml(const Object* object)
{
    QDomDocument xml(object->className());
    xml.appendChild(object->save());
    return xml;
}

QString Sigmod::Object::unused(const QString& variable)
{
    return QString("Setting unused variable %1").arg(variable);
}

QString Sigmod::Object::bounds(const QString& variable)
{
    return QString("Value for %1 out-of-bounds").arg(variable);
}

QString Sigmod::Object::subclass(const QString& subclass, const int id)
{
    return QString("Duplicate %1 with id %2").arg(subclass, id);
}

QString Sigmod::Object::subclass(const QString& subclass, const QString& name)
{
    return QString("Duplicate %1 with name %2").arg(subclass, name);
}

void Sigmod::Object::clear()
{
}
