/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_SOUND
#define SIGMOD_SOUND

// Sigmod includes
#include "Object.h"

// Qt includes
#include <QtCore/QByteArray>
#include <QtCore/QString>

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Sound : public Object
{
    Q_OBJECT
    Q_ENUMS(Type)
    
    public:
        enum Type
        {
            SoundEffect = 0,
            Music = 1
        };
        static const QStringList TypeStr;
        
        Sound(const Sound& sound);
        Sound(const Sigmod* parent, const int id);
        Sound(const Sound& sound, const Sigmod* parent, const int id);
        Sound(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setType(const Type type);
        void setData(const QByteArray& data);
        
        QString name() const;
        Type type() const;
        QByteArray data() const;
        
        Sound& operator=(const Sound& rhs);
    private:
        QString m_name;
        Type m_type;
        QByteArray m_data;
};
}
Q_DECLARE_METATYPE(Sigmod::Sound::Type)

#endif
