/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesAbility.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"
#include "Species.h"

Sigmod::SpeciesAbility::SpeciesAbility(const SpeciesAbility& ability) :
        Object(ability.parent(), ability.id())
{
    *this = ability;
}

Sigmod::SpeciesAbility::SpeciesAbility(const Species* parent, const int id) :
        Object(parent, id),
        m_ability(INT_MAX),
        m_weight(1)
{
}

Sigmod::SpeciesAbility::SpeciesAbility(const SpeciesAbility& ability, const Species* parent, const int id) :
        Object(parent, id)
{
    *this = ability;
}

Sigmod::SpeciesAbility::SpeciesAbility(const QDomElement& xml, const Species* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::SpeciesAbility::validate()
{
    TEST_BEGIN();
    TEST(setAbility, ability);
    TEST(setWeight, weight);
    TEST_END();
}

void Sigmod::SpeciesAbility::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(ability);
    LOAD(weight);
}

QDomElement Sigmod::SpeciesAbility::save() const
{
    SAVE_CREATE();
    SAVE(ability);
    SAVE(weight);
    return xml;
}

void Sigmod::SpeciesAbility::setAbility(const int ability)
{
    if (qobject_cast<const Sigmod*>(sigmod())->abilityIndex(ability) == INT_MAX)
        emit(error(bounds("ability")));
    else
        CHECK(ability);
}

void Sigmod::SpeciesAbility::setWeight(const int weight)
{
    if (!weight)
        emit(error(bounds("weight")));
    else
        CHECK(weight);
}

int Sigmod::SpeciesAbility::ability() const
{
    return m_ability;
}

int Sigmod::SpeciesAbility::weight() const
{
    return m_weight;
}

Sigmod::SpeciesAbility& Sigmod::SpeciesAbility::operator=(const SpeciesAbility& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(ability);
    COPY(weight);
    return *this;
}
