/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesItem.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"
#include "Species.h"

Sigmod::SpeciesItem::SpeciesItem(const SpeciesItem& item) :
        Object(item.parent(), item.id())
{
    *this = item;
}

Sigmod::SpeciesItem::SpeciesItem(const Species* parent, const int id) :
        Object(parent, id),
        m_item(INT_MAX),
        m_weight(1)
{
}

Sigmod::SpeciesItem::SpeciesItem(const SpeciesItem& item, const Species* parent, const int id) :
        Object(parent, id)
{
    *this = item;
}

Sigmod::SpeciesItem::SpeciesItem(const QDomElement& xml, const Species* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::SpeciesItem::validate()
{
    TEST_BEGIN();
    TEST(setItem, item);
    TEST(setWeight, weight);
    TEST_END();
}

void Sigmod::SpeciesItem::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(item);
    LOAD(weight);
}

QDomElement Sigmod::SpeciesItem::save() const
{
    SAVE_CREATE();
    SAVE(item);
    SAVE(weight);
    return xml;
}

void Sigmod::SpeciesItem::setItem(const int item)
{
    if (qobject_cast<const Sigmod*>(sigmod())->itemIndex(item) == INT_MAX)
        emit(error(bounds("item")));
    else
        CHECK(item);
}

void Sigmod::SpeciesItem::setWeight(const int weight)
{
    if (!weight)
        emit(error(bounds("weight")));
    else
        CHECK(weight);
}

int Sigmod::SpeciesItem::item() const
{
    return m_item;
}

int Sigmod::SpeciesItem::weight() const
{
    return m_weight;
}

Sigmod::SpeciesItem& Sigmod::SpeciesItem::operator=(const SpeciesItem& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(item);
    COPY(weight);
    return *this;
}
