/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesMove.h"

// Sigmod includes
#include "Macros.h"
#include "Rules.h"
#include "Sigmod.h"
#include "Species.h"

Sigmod::SpeciesMove::SpeciesMove(const SpeciesMove& move) :
        Object(move.parent(), move.id())
{
    *this = move;
}

Sigmod::SpeciesMove::SpeciesMove(const Species* parent, const int id) :
        Object(parent, id),
        m_move(INT_MAX),
        m_level(0),
        m_wild(0)
{
}

Sigmod::SpeciesMove::SpeciesMove(const SpeciesMove& move, const Species* parent, const int id) :
        Object(parent, id)
{
    *this = move;
}

Sigmod::SpeciesMove::SpeciesMove(const QDomElement& xml, const Species* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::SpeciesMove::validate()
{
    TEST_BEGIN();
    TEST(setMove, move);
    TEST(setLevel, level);
    TEST(setWild, wild);
    TEST_END();
}

void Sigmod::SpeciesMove::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(move);
    LOAD(level);
    LOAD(wild);
}

QDomElement Sigmod::SpeciesMove::save() const
{
    SAVE_CREATE();
    SAVE(move);
    SAVE(level);
    SAVE(wild);
    return xml;
}

void Sigmod::SpeciesMove::setMove(const int move)
{
    if (qobject_cast<const Sigmod*>(sigmod())->moveIndex(move) == INT_MAX)
        emit(error(bounds("move")));
    else
        CHECK(move);
}

void Sigmod::SpeciesMove::setLevel(const int level)
{
    if (qobject_cast<const Sigmod*>(sigmod())->rules()->maxLevel() <= level)
        emit(error(bounds("level")));
    else
        CHECK(level);
}

void Sigmod::SpeciesMove::setWild(const int wild)
{
    if (!wild || (qobject_cast<const Sigmod*>(sigmod())->rules()->maxLevel() <= wild))
        emit(error(bounds("wild")));
    else
        CHECK(wild);
}

int Sigmod::SpeciesMove::move() const
{
    return m_move;
}

int Sigmod::SpeciesMove::level() const
{
    return m_level;
}

int Sigmod::SpeciesMove::wild() const
{
    return m_wild;
}

Sigmod::SpeciesMove& Sigmod::SpeciesMove::operator=(const SpeciesMove& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(move);
    COPY(level);
    COPY(wild);
    return *this;
}
