/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Sprite.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

Sigmod::Sprite::Sprite(const Sprite& sprite) :
        Object(sprite.parent(), sprite.id())
{
    *this = sprite;
}

Sigmod::Sprite::Sprite(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_sprite()
{
}

Sigmod::Sprite::Sprite(const Sprite& sprite, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = sprite;
}

Sigmod::Sprite::Sprite(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

Sigmod::Sprite::~Sprite()
{
}

void Sigmod::Sprite::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::Sprite::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(sprite);
}

QDomElement Sigmod::Sprite::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(sprite);
    return xml;
}

void Sigmod::Sprite::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Sprite::setSprite(const QImage& sprite)
{
    m_sprite = sprite;
    emit(changed());
}

QString Sigmod::Sprite::name() const
{
    return m_name;
}

QImage Sigmod::Sprite::sprite() const
{
    return m_sprite;
}

Sigmod::Sprite& Sigmod::Sprite::operator=(const Sprite& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(sprite);
    return *this;
}
