/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_STATUS
#define SIGMOD_STATUS

// Sigmod includes
#include "Object.h"
#include "Script.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Status : public Object
{
    Q_OBJECT
    
    public:
        Status(const Status& status);
        Status(const Sigmod* parent, const int id);
        Status(const Status& status, const Sigmod* parent, const int id);
        Status(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        ~Status();
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setBattleScript(const Script& battleScript);
        void setWorldScript(const Script& worldScript);
        
        QString name() const;
        Script battleScript() const;
        Script worldScript() const;
        
        Status& operator=(const Status& rhs);
    private:
        QString m_name;
        Script m_battleScript;
        Script m_worldScript;
};
}

#endif
