/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Store.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

Sigmod::Store::Store(const Store& store) :
        Object(store.parent(), store.id())
{
    *this = store;
}

Sigmod::Store::Store(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name("")
{
}

Sigmod::Store::Store(const Store& store, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = store;
}

Sigmod::Store::Store(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Store::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    if (m_item.size())
        TEST_LIST(setItem, item);
    else
        emit(error("No items in the store"));
    TEST_END();
}

void Sigmod::Store::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD_LIST(item);
}

QDomElement Sigmod::Store::save() const
{
    SAVE_CREATE();
    SAVE_LIST(item);
    return xml;
}

void Sigmod::Store::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Store::setItem(const int item, const bool state)
{
    if (qobject_cast<const Sigmod*>(sigmod())->itemIndex(item) == INT_MAX)
        emit(error(bounds("item")));
    else if (state && !m_item.contains(item))
    {
        m_item.append(item);
        emit(changed());
    }
    else if (m_item.contains(item))
    {
        m_item.removeAll(item);
        emit(changed());
    }
}

QString Sigmod::Store::name() const
{
    return m_name;
}

bool Sigmod::Store::item(const int item) const
{
    return m_item.contains(item);
}

QList<int> Sigmod::Store::items() const
{
    return m_item;
}

Sigmod::Store& Sigmod::Store::operator=(const Store& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(item);
    return *this;
}
