/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Time.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

Sigmod::Time::Time(const Time& time) :
        Object(time.parent(), time.id())
{
    *this = time;
}

Sigmod::Time::Time(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_hour(0),
        m_minute(0)
{
}

Sigmod::Time::Time(const Time& time, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = time;
}

Sigmod::Time::Time(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Time::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST(setHour, hour);
    TEST(setMinute, minute);
    TEST_END();
}

void Sigmod::Time::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(hour);
    LOAD(minute);
}

QDomElement Sigmod::Time::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(hour);
    SAVE(minute);
    return xml;
}

void Sigmod::Time::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Time::setHour(const int hour)
{
    if (24 <= hour)
        emit(error(bounds("hour")));
    else
        CHECK(hour);
}

void Sigmod::Time::setMinute(const int minute)
{
    if (60 <= minute)
        emit(error(bounds("minute")));
    else
        CHECK(minute);
}

QString Sigmod::Time::name() const
{
    return m_name;
}

int Sigmod::Time::hour() const
{
    return m_hour;
}

int Sigmod::Time::minute() const
{
    return m_minute;
}

Sigmod::Time& Sigmod::Time::operator=(const Time& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(hour);
    COPY(minute);
    return *this;
}
