/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Type.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

Sigmod::Type::Type(const Type& type) :
        Object(type.parent(), type.id())
{
    *this = type;
}

Sigmod::Type::Type(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_stab(1, 1)
{
}

Sigmod::Type::Type(const Type& type, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = type;
}

Sigmod::Type::Type(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Type::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::Type::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(stab);
}

QDomElement Sigmod::Type::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(stab);
    return xml;
}

void Sigmod::Type::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Type::setStab(const Fraction& stab)
{
    if (stab < 1)
        emit(error(bounds("stab")));
    else
        CHECK(stab);
}

QString Sigmod::Type::name() const
{
    return m_name;
}

Sigmod::Fraction Sigmod::Type::stab() const
{
    return m_stab;
}

Sigmod::Type& Sigmod::Type::operator=(const Type& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(stab);
    return *this;
}
