/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Weather.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"
#include "Script.h"

Sigmod::Weather::Weather(const Weather& weather) :
        Object(weather.parent(), weather.id())
{
    *this = weather;
}

Sigmod::Weather::Weather(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_script("", "")
{
}

Sigmod::Weather::Weather(const Weather& weather, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = weather;
}

Sigmod::Weather::Weather(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

Sigmod::Weather::~Weather()
{
}

void Sigmod::Weather::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::Weather::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(script);
}

QDomElement Sigmod::Weather::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(script);
    return xml;
}

void Sigmod::Weather::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Weather::setScript(const Script& script)
{
    CHECK(script);
}

QString Sigmod::Weather::name() const
{
    return m_name;
}

Sigmod::Script Sigmod::Weather::script() const
{
    return m_script;
}

Sigmod::Weather& Sigmod::Weather::operator=(const Weather& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(script);
    return *this;
}
