/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "AbilityUI.h"

// Sigmod includes
#include "../sigmod/Ability.h"

Sigmodr::AbilityUI::AbilityUI(Sigmod::Ability* ability, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(ability, new Sigmod::Ability(*ability));
}

Sigmodr::AbilityUI::~AbilityUI()
{
}

void Sigmodr::AbilityUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Ability*>(modified())->name());
    varPriority->setValue(qobject_cast<Sigmod::Ability*>(modified())->priority());
    varDescription->setText(qobject_cast<Sigmod::Ability*>(modified())->description());
    varBattleScript->setValue(qobject_cast<Sigmod::Ability*>(modified())->battleScript());
    varWorldScript->setValue(qobject_cast<Sigmod::Ability*>(modified())->worldScript());
    varPriorityScript->setValue(qobject_cast<Sigmod::Ability*>(modified())->priorityScript());
}

void Sigmodr::AbilityUI::apply()
{
    *qobject_cast<Sigmod::Ability*>(original()) = *qobject_cast<Sigmod::Ability*>(modified());
    emit(changed(false));
}

void Sigmodr::AbilityUI::discard()
{
    *qobject_cast<Sigmod::Ability*>(modified()) = *qobject_cast<Sigmod::Ability*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::AbilityUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Ability*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::AbilityUI::on_varPriority_valueChanged(const int priority)
{
    qobject_cast<Sigmod::Ability*>(modified())->setPriority(priority);
}

void Sigmodr::AbilityUI::on_varDescription_textChanged(const QString& description)
{
    qobject_cast<Sigmod::Ability*>(modified())->setDescription(description);
}

void Sigmodr::AbilityUI::on_varBattleScript_valueChanged(const Sigmod::Script& battleScript)
{
    qobject_cast<Sigmod::Ability*>(modified())->setBattleScript(battleScript);
}

void Sigmodr::AbilityUI::on_varWorldScript_valueChanged(const Sigmod::Script& worldScript)
{
    qobject_cast<Sigmod::Ability*>(modified())->setWorldScript(worldScript);
}

void Sigmodr::AbilityUI::on_varPriorityScript_valueChanged(const Sigmod::Script& priorityScript)
{
    qobject_cast<Sigmod::Ability*>(modified())->setPriorityScript(priorityScript);
}
