/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "AuthorUI.h"

// Sigmod includes
#include "../sigmod/Author.h"

Sigmodr::AuthorUI::AuthorUI(Sigmod::Author* author, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(author, new Sigmod::Author(*author));
}

Sigmodr::AuthorUI::~AuthorUI()
{
}

void Sigmodr::AuthorUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Author*>(modified())->name());
    varEmail->setText(qobject_cast<Sigmod::Author*>(modified())->email());
    varRole->setText(qobject_cast<Sigmod::Author*>(modified())->role());
}

void Sigmodr::AuthorUI::apply()
{
    *qobject_cast<Sigmod::Author*>(original()) = *qobject_cast<Sigmod::Author*>(modified());
    emit(changed(false));
}

void Sigmodr::AuthorUI::discard()
{
    *qobject_cast<Sigmod::Author*>(modified()) = *qobject_cast<Sigmod::Author*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::AuthorUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Author*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::AuthorUI::on_varEmail_textChanged(const QString& email)
{
    const int cursor = varEmail->cursorPosition();
    qobject_cast<Sigmod::Author*>(modified())->setEmail(email);
    varEmail->setCursorPosition(cursor);
}

void Sigmodr::AuthorUI::on_varRole_textChanged(const QString& role)
{
    const int cursor = varRole->cursorPosition();
    qobject_cast<Sigmod::Author*>(modified())->setRole(role);
    varRole->setCursorPosition(cursor);
}
