/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "GlobalScriptUI.h"

// Sigmod includes
#include "../sigmod/GlobalScript.h"

Sigmodr::GlobalScriptUI::GlobalScriptUI(Sigmod::GlobalScript* globalScript, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(globalScript, new Sigmod::GlobalScript(*globalScript));
}

Sigmodr::GlobalScriptUI::~GlobalScriptUI()
{
}

void Sigmodr::GlobalScriptUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::GlobalScript*>(modified())->name());
    varScript->setValue(qobject_cast<Sigmod::GlobalScript*>(modified())->script());
}

void Sigmodr::GlobalScriptUI::apply()
{
    *qobject_cast<Sigmod::GlobalScript*>(original()) = *qobject_cast<Sigmod::GlobalScript*>(modified());
    emit(changed(false));
}

void Sigmodr::GlobalScriptUI::discard()
{
    *qobject_cast<Sigmod::GlobalScript*>(modified()) = *qobject_cast<Sigmod::GlobalScript*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::GlobalScriptUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::GlobalScript*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::GlobalScriptUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::GlobalScript*>(modified())->setScript(script);
}
