/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ItemUI.h"

// Sigmod includes
#include "../sigmod/Item.h"
#include "../sigmod/ItemType.h"
#include "../sigmod/Rules.h"
#include "../sigmod/Sigmod.h"

Sigmodr::ItemUI::ItemUI(Sigmod::Item* item, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(item, new Sigmod::Item(*item));
}

Sigmodr::ItemUI::~ItemUI()
{
}

void Sigmodr::ItemUI::refreshGui()
{
    varType->clear();
    for (int i = 0; i < sigmod()->itemTypeCount(); ++i)
    {
        const Sigmod::ItemType* itemType = sigmod()->itemType(i);
        varType->addItem(itemType->name(), itemType->id());
    }
    varPrice->setMaximum(sigmod()->rules()->maxMoney());
}

void Sigmodr::ItemUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Item*>(modified())->name());
    boxSellable->setChecked(qobject_cast<Sigmod::Item*>(modified())->sellable() ? Qt::Checked : Qt::Unchecked);
    varType->setCurrentIndex(varType->findData(qobject_cast<Sigmod::Item*>(modified())->type()));
    varPrice->setValue(qobject_cast<Sigmod::Item*>(modified())->price());
    varDescription->setText(qobject_cast<Sigmod::Item*>(modified())->description());
    varScript->setValue(qobject_cast<Sigmod::Item*>(modified())->script());
}

void Sigmodr::ItemUI::apply()
{
    *qobject_cast<Sigmod::Item*>(original()) = *qobject_cast<Sigmod::Item*>(modified());
    emit(changed(false));
}

void Sigmodr::ItemUI::discard()
{
    *qobject_cast<Sigmod::Item*>(modified()) = *qobject_cast<Sigmod::Item*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::ItemUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Item*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::ItemUI::on_boxSellable_toggled(const bool sellable)
{
    qobject_cast<Sigmod::Item*>(modified())->setSellable(sellable);
}

void Sigmodr::ItemUI::on_varType_activated(const int type)
{
    qobject_cast<Sigmod::Item*>(modified())->setType(varType->itemData(type).toInt());
}

void Sigmodr::ItemUI::on_varPrice_valueChanged(const int price)
{
    qobject_cast<Sigmod::Item*>(modified())->setPrice(price);
}

void Sigmodr::ItemUI::on_varDescription_textChanged(const QString& description)
{
    qobject_cast<Sigmod::Item*>(modified())->setDescription(description);
}

void Sigmodr::ItemUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::Item*>(modified())->setScript(script);
}
