/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapEffectUI.h"

// Sigmod includes
#include "../sigmod/Item.h"
#include "../sigmod/Map.h"
#include "../sigmod/MapEffect.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Skin.h"

Sigmodr::MapEffectUI::MapEffectUI(Sigmod::MapEffect* effect, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(effect, new Sigmod::MapEffect(*effect));
}

Sigmodr::MapEffectUI::~MapEffectUI()
{
}

void Sigmodr::MapEffectUI::refreshGui()
{
    varCoordinate->setMaximum(qobject_cast<const Sigmod::Map*>(original()->parent())->size());
    for (int i = 0; i < sigmod()->skinCount(); ++i)
    {
        const Sigmod::Skin* skin = sigmod()->skin(i);
        varSkin->addItem(skin->name(), skin->id());
    }
}

void Sigmodr::MapEffectUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::MapEffect*>(modified())->name());
    varCoordinate->setValue(qobject_cast<Sigmod::MapEffect*>(modified())->coordinate());
    varSkin->setCurrentIndex(varSkin->findData(qobject_cast<Sigmod::MapEffect*>(modified())->skin()));
    varScript->setValue(qobject_cast<Sigmod::MapEffect*>(modified())->script());
    varIsGhost->setChecked(qobject_cast<Sigmod::MapEffect*>(modified())->isGhost() ? Qt::Checked : Qt::Unchecked);
}

void Sigmodr::MapEffectUI::apply()
{
    *qobject_cast<Sigmod::MapEffect*>(original()) = *qobject_cast<Sigmod::MapEffect*>(modified());
    emit(changed(false));
}

void Sigmodr::MapEffectUI::discard()
{
    *qobject_cast<Sigmod::MapEffect*>(modified()) = *qobject_cast<Sigmod::MapEffect*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::MapEffectUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::MapEffect*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::MapEffectUI::on_varCoordinate_valueChanged(const QPoint& coordinate)
{
    qobject_cast<Sigmod::MapEffect*>(modified())->setCoordinate(coordinate);
}

void Sigmodr::MapEffectUI::on_varSkin_currentIndexChanged(const int skin)
{
    qobject_cast<Sigmod::MapEffect*>(modified())->setSkin(varSkin->itemData(skin).toInt());
}

void Sigmodr::MapEffectUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::MapEffect*>(modified())->setScript(script);
}

void Sigmodr::MapEffectUI::on_varIsGhost_clicked(const bool isGhost)
{
    qobject_cast<Sigmod::MapEffect*>(modified())->setIsGhost(isGhost);
}
