/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapTrainerUI.h"

// Sigmod includes
#include "../sigmod/Map.h"
#include "../sigmod/MapTrainer.h"
#include "../sigmod/MapTrainerTeamMember.h"
#include "../sigmod/Rules.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Species.h"
#include "../sigmod/Trainer.h"

Sigmodr::MapTrainerUI::MapTrainerUI(Sigmod::MapTrainer* trainer, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(trainer, new Sigmod::MapTrainer(*trainer));
}

Sigmodr::MapTrainerUI::~MapTrainerUI()
{
}

void Sigmodr::MapTrainerUI::refreshGui()
{
    varTrainerClass->clear();
    for (int i = 0; i < sigmod()->trainerCount(); ++i)
    {
        const Sigmod::Trainer* trainer = sigmod()->trainer(i);
        varTrainerClass->addItem(trainer->name(), trainer->id());
    }
    varCoordinate->setMaximum(qobject_cast<const Sigmod::Map*>(original()->parent())->size());
    varNumberFight->setMaximum(sigmod()->rules()->maxFight());
    varLeadTeamMember->clear();
    for (int i = 0; i < qobject_cast<Sigmod::MapTrainer*>(original())->teamMemberCount(); ++i)
    {
        const Sigmod::MapTrainerTeamMember* teamMember = qobject_cast<Sigmod::MapTrainer*>(original())->teamMember(i);
        const Sigmod::Species* species = sigmod()->species(teamMember->species());
        if (species)
            varLeadTeamMember->addItem(species->name(), teamMember->id());
        else
            varLeadTeamMember->addItem("Invalid Species", teamMember->id());
    }
}

void Sigmodr::MapTrainerUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::MapTrainer*>(modified())->name());
    varTrainerClass->setCurrentIndex(varTrainerClass->findData(qobject_cast<Sigmod::MapTrainer*>(modified())->trainerClass()));
    varCoordinate->setValue(qobject_cast<Sigmod::MapTrainer*>(modified())->coordinate());
    varNumberFight->setValue(qobject_cast<Sigmod::MapTrainer*>(modified())->numberFight());
    varScript->setValue(qobject_cast<Sigmod::MapTrainer*>(modified())->script());
    varLeadTeamMember->setCurrentIndex(varLeadTeamMember->findData(qobject_cast<Sigmod::MapTrainer*>(modified())->leadTeamMember()));
}

void Sigmodr::MapTrainerUI::apply()
{
    *qobject_cast<Sigmod::MapTrainer*>(original()) = *qobject_cast<Sigmod::MapTrainer*>(modified());
    emit(changed(false));
}

void Sigmodr::MapTrainerUI::discard()
{
    *qobject_cast<Sigmod::MapTrainer*>(modified()) = *qobject_cast<Sigmod::MapTrainer*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::MapTrainerUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::MapTrainer*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::MapTrainerUI::on_varTrainerClass_activated(const int trainerClass)
{
    qobject_cast<Sigmod::MapTrainer*>(modified())->setTrainerClass(varTrainerClass->itemData(trainerClass).toInt());
}

void Sigmodr::MapTrainerUI::on_varCoordinate_valueChanged(const QPoint& coordinate)
{
    qobject_cast<Sigmod::MapTrainer*>(modified())->setCoordinate(coordinate);
}

void Sigmodr::MapTrainerUI::on_varNumberFight_valueChanged(const int numberFight)
{
    qobject_cast<Sigmod::MapTrainer*>(modified())->setNumberFight(numberFight);
}

void Sigmodr::MapTrainerUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::MapTrainer*>(modified())->setScript(script);
}

void Sigmodr::MapTrainerUI::on_varLeadTeamMember_activated(const int leadTeamMember)
{
    qobject_cast<Sigmod::MapTrainer*>(modified())->setLeadTeamMember(leadTeamMember);
}
