/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWarpUI.h"

// Sigmod includes
#include "../sigmod/Map.h"
#include "../sigmod/MapWarp.h"
#include "../sigmod/Sigmod.h"

Sigmodr::MapWarpUI::MapWarpUI(Sigmod::MapWarp* warp, QWidget* parent) :
        ObjectUI(parent),
        m_lastMap(-1)
{
    setupUi(this);
    setObjects(warp, new Sigmod::MapWarp(*warp));
}

Sigmodr::MapWarpUI::~MapWarpUI()
{
}

void Sigmodr::MapWarpUI::initGui()
{
    varType->addItem(Sigmod::MapWarp::TypeStr[Sigmod::MapWarp::Door], QVariant::fromValue(Sigmod::MapWarp::Door));
    varType->addItem(Sigmod::MapWarp::TypeStr[Sigmod::MapWarp::Warp], QVariant::fromValue(Sigmod::MapWarp::Warp));
    varType->addItem(Sigmod::MapWarp::TypeStr[Sigmod::MapWarp::Hole], QVariant::fromValue(Sigmod::MapWarp::Hole));
    varType->addItem(Sigmod::MapWarp::TypeStr[Sigmod::MapWarp::Boundary], QVariant::fromValue(Sigmod::MapWarp::Boundary));
}

void Sigmodr::MapWarpUI::refreshGui()
{
    varCoordinate->setMaximum(qobject_cast<const Sigmod::Map*>(original()->parent())->size());
    varToMap->clear();
    for (int i = 0; i < sigmod()->mapCount(); ++i)
    {
        const Sigmod::Map* map = sigmod()->map(i);
        varToMap->addItem(map->name(), map->id());
    }
}

void Sigmodr::MapWarpUI::setGui()
{
    const bool resetWarps = (qobject_cast<Sigmod::MapWarp*>(modified())->toMap() != m_lastMap);
    varName->setText(qobject_cast<Sigmod::MapWarp*>(modified())->name());
    varCoordinate->setValue(qobject_cast<Sigmod::MapWarp*>(modified())->coordinate());
    varType->setCurrentIndex(qobject_cast<Sigmod::MapWarp*>(modified())->type());
    varToMap->setCurrentIndex(varToMap->findData(qobject_cast<Sigmod::MapWarp*>(modified())->toMap()));
    m_lastMap = qobject_cast<Sigmod::MapWarp*>(modified())->toMap();
    if (resetWarps)
    {
        varToWarp->clear();
        const Sigmod::Map* map = sigmod()->mapById(qobject_cast<Sigmod::MapWarp*>(modified())->toMap());
        if (map)
        {
            for (int i = 0; i < map->warpCount(); ++i)
            {
                const Sigmod::MapWarp* warp = map->warp(i);
                varToWarp->addItem(warp->name(), warp->id());
            }
        }
    }
    varToWarp->setCurrentIndex(varToMap->findData(qobject_cast<Sigmod::MapWarp*>(modified())->toWarp()));
    varScript->setValue(qobject_cast<Sigmod::MapWarp*>(modified())->script());
}

void Sigmodr::MapWarpUI::apply()
{
    *qobject_cast<Sigmod::MapWarp*>(original()) = *qobject_cast<Sigmod::MapWarp*>(modified());
    emit(changed(false));
}

void Sigmodr::MapWarpUI::discard()
{
    *qobject_cast<Sigmod::MapWarp*>(modified()) = *qobject_cast<Sigmod::MapWarp*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::MapWarpUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::MapWarp*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::MapWarpUI::on_varCoordinate_valueChanged(const QPoint& coordinate)
{
    qobject_cast<Sigmod::MapWarp*>(modified())->setCoordinate(coordinate);
}

void Sigmodr::MapWarpUI::on_varType_activated(const int type)
{
    qobject_cast<Sigmod::MapWarp*>(modified())->setType(varType->itemData(type).value<Sigmod::MapWarp::Type>());
}

void Sigmodr::MapWarpUI::on_varToMap_activated(const int toMap)
{
    qobject_cast<Sigmod::MapWarp*>(modified())->setToMap(toMap);
}

void Sigmodr::MapWarpUI::on_varToWarp_activated(const int toWarp)
{
    qobject_cast<Sigmod::MapWarp*>(modified())->setToWarp(toWarp);
}

void Sigmodr::MapWarpUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::MapWarp*>(modified())->setScript(script);
}
