/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "NatureUI.h"

// Sigmod includes
#include "../sigmod/Nature.h"
#include "../sigmod/Rules.h"
#include "../sigmod/Sigmod.h"

Sigmodr::NatureUI::NatureUI(Sigmod::Nature* nature, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(nature, new Sigmod::Nature(*nature));
}

Sigmodr::NatureUI::~NatureUI()
{
}

void Sigmodr::NatureUI::initGui()
{
    connect(varStat, SIGNAL(activated()), this, SLOT(setGui()));
}

void Sigmodr::NatureUI::refreshGui()
{
    varStat->clear();
    const bool isSplit = sigmod()->rules()->specialSplit();
    const QStringList& statNames = (isSplit ? Sigmod::StatGSCStr : Sigmod::StatRBYStr);
    varStat->addItem(statNames[Sigmod::ST_Attack], QVariant::fromValue(Sigmod::ST_Attack));
    varStat->addItem(statNames[Sigmod::ST_Defense], QVariant::fromValue(Sigmod::ST_Defense));
    varStat->addItem(statNames[Sigmod::ST_Speed], QVariant::fromValue(Sigmod::ST_Speed));
    if (isSplit)
    {
        varStat->addItem(statNames[Sigmod::ST_SpecialAttack], QVariant::fromValue(Sigmod::ST_SpecialAttack));
        varStat->addItem(statNames[Sigmod::ST_SpecialDefense], QVariant::fromValue(Sigmod::ST_SpecialDefense));
    }
    else
        varStat->addItem(statNames[Sigmod::ST_Special], QVariant::fromValue(Sigmod::ST_Special));
}

void Sigmodr::NatureUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Nature*>(modified())->name());
    varStatMultiplier->setValue(qobject_cast<Sigmod::Nature*>(modified())->stat(varStat->itemData(varStat->currentIndex()).value<Sigmod::Stat>()));
    varWeight->setValue(qobject_cast<Sigmod::Nature*>(modified())->weight());
}

void Sigmodr::NatureUI::apply()
{
    *qobject_cast<Sigmod::Nature*>(original()) = *qobject_cast<Sigmod::Nature*>(modified());
    emit(changed(false));
}

void Sigmodr::NatureUI::discard()
{
    *qobject_cast<Sigmod::Nature*>(modified()) = *qobject_cast<Sigmod::Nature*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::NatureUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Nature*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::NatureUI::on_varStatMultiplier_valueChanged(const Sigmod::Fraction& statMultiplier)
{
    qobject_cast<Sigmod::Nature*>(modified())->setStat(varStat->itemData(varStat->currentIndex()).value<Sigmod::Stat>(), statMultiplier);
}

void Sigmodr::NatureUI::on_varWeight_valueChanged(const int weight)
{
    qobject_cast<Sigmod::Nature*>(modified())->setWeight(weight);
}
