/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "PointWidget.h"

Sigmodr::PointWidget::PointWidget(QWidget* parent, const QPoint& value) :
        QWidget(parent),
        m_value(value)
{
    setupUi(this);
}

QPoint Sigmodr::PointWidget::value() const
{
    return m_value;
}

void Sigmodr::PointWidget::setValue(const QPoint& value)
{
    if (m_value == value)
        return;
    m_value = value;
    varX->setValue(m_value.x());
    varY->setValue(m_value.y());
    emit(valueChanged(m_value));
}

void Sigmodr::PointWidget::setMaximum(const QPoint& maximum)
{
    varX->setMaximum(maximum.x());
    varY->setMaximum(maximum.y());
}

void Sigmodr::PointWidget::on_varX_valueChanged(const int x)
{
    m_value.setX(x);
    emit(valueChanged(m_value));
}

void Sigmodr::PointWidget::on_varY_valueChanged(const int y)
{
    m_value.setY(y);
    emit(valueChanged(m_value));
}
