/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMODR_SPECIESUI
#define SIGMODR_SPECIESUI

// Sigmodr includes
#include "ObjectUI.h"

// Form include
#include "ui_species.h"

// Forward declarations
namespace Sigmod
{
class Species;
}

namespace Sigmodr
{
class SpeciesUI : public ObjectUI, private Ui::formSpecies
{
    Q_OBJECT
    
    public:
        SpeciesUI(Sigmod::Species* species, QWidget* parent);
        ~SpeciesUI();
    public slots:
        void apply();
        void discard();
    protected slots:
        void on_varName_textChanged(const QString& name);
        void on_varBaseStatValue_valueChanged(const int baseStat);
        void on_varEffortValue_valueChanged(const int effortValue);
        void on_varGrowth_activated(const int growth);
        void on_varExperienceValue_valueChanged(const int experienceValue);
        void on_varCatchValue_valueChanged(const int catchValue);
        void on_varRunChance_valueChanged(const Sigmod::Fraction& runChance);
        void on_varItemChance_valueChanged(const Sigmod::Fraction& itemChance);
        void on_varEncyclopediaNumber_valueChanged(const int encyclopediaNumber);
        void on_varWeight_valueChanged(const int weight);
        void on_varHeight_valueChanged(const int height);
        void on_varEncyclopediaEntry_textChanged(const QString& encyclopediaEntry);
        void on_varMaleFront_currentIndexChanged(const int maleFront);
        void on_varMaleBack_currentIndexChanged(const int maleBack);
        void on_varFemaleFront_currentIndexChanged(const int femaleFront);
        void on_varFemaleBack_currentIndexChanged(const int femaleBack);
        void on_varSkin_currentIndexChanged(const int skin);
        void on_boxGenderChance_clicked(const bool genderUsed);
        void on_varGenderChance_valueChanged(const Sigmod::Fraction& genderChance);
        void on_varEggSpecies_activated(const int eggSpecies);
        void on_varEggSteps_valueChanged(const int eggSteps);
        void on_varEvolution_valueChanged(const Sigmod::Script& evolution);
        void on_varTypes_itemClicked(QListWidgetItem* item);
        void on_varEggGroups_itemClicked(QListWidgetItem* item);
    private slots:
        void initGui();
        void refreshGui();
        void setGui();
};
}

#endif
