/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpriteUI.h"

// Sigmod includes
#include "../sigmod/Sigmod.h"
#include "../sigmod/Sprite.h"

// KDE includes
#include <KFileDialog>
#include <KImageFilePreview>

Sigmodr::SpriteUI::SpriteUI(Sigmod::Sprite* sprite, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(sprite, new Sigmod::Sprite(*sprite));
}

Sigmodr::SpriteUI::~SpriteUI()
{
}

void Sigmodr::SpriteUI::setGui()
{
    const QImage sprite = qobject_cast<Sigmod::Sprite*>(modified())->sprite();
    varName->setText(qobject_cast<Sigmod::Sprite*>(modified())->name());
    varSprite->setIcon(QPixmap::fromImage(sprite));
    varSprite->setMinimumSize(sprite.size());
}

void Sigmodr::SpriteUI::apply()
{
    *qobject_cast<Sigmod::Sprite*>(original()) = *qobject_cast<Sigmod::Sprite*>(modified());
    emit(changed(false));
}

void Sigmodr::SpriteUI::discard()
{
    *qobject_cast<Sigmod::Sprite*>(modified()) = *qobject_cast<Sigmod::Sprite*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::SpriteUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Sprite*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::SpriteUI::on_varSprite_pressed()
{
    KFileDialog* dialog = new KFileDialog(KUrl("kfiledialog:///image"), "image/*|Image files", NULL);
    dialog->setCaption("Use Image File");
    dialog->setOperationMode(KFileDialog::Opening);
    dialog->setPreviewWidget(new KImageFilePreview);
    if (dialog->exec() == QDialog::Accepted)
    {
        qobject_cast<Sigmod::Sprite*>(modified())->setSprite(QImage(dialog->selectedFile()));
        setGui();
    }
    delete dialog;
}
