/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "StatusUI.h"

// Sigmod includes
#include "../sigmod/Status.h"

Sigmodr::StatusUI::StatusUI(Sigmod::Status* status, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(status, new Sigmod::Status(*status));
}

Sigmodr::StatusUI::~StatusUI()
{
}

void Sigmodr::StatusUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Status*>(modified())->name());
    varBattleScript->setValue(qobject_cast<Sigmod::Status*>(modified())->battleScript());
    varWorldScript->setValue(qobject_cast<Sigmod::Status*>(modified())->worldScript());
}

void Sigmodr::StatusUI::apply()
{
    *qobject_cast<Sigmod::Status*>(original()) = *qobject_cast<Sigmod::Status*>(modified());
    emit(changed(false));
}

void Sigmodr::StatusUI::discard()
{
    *qobject_cast<Sigmod::Status*>(modified()) = *qobject_cast<Sigmod::Status*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::StatusUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Status*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::StatusUI::on_varBattleScript_valueChanged(const Sigmod::Script& battleScript)
{
    qobject_cast<Sigmod::Status*>(modified())->setBattleScript(battleScript);
}

void Sigmodr::StatusUI::on_varWorldScript_valueChanged(const Sigmod::Script& worldScript)
{
    qobject_cast<Sigmod::Status*>(modified())->setWorldScript(worldScript);
}
