/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "StoreUI.h"

// Sigmod includes
#include "../sigmod/Item.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Store.h"

Sigmodr::StoreUI::StoreUI(Sigmod::Store* store, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(store, new Sigmod::Store(*store));
}

Sigmodr::StoreUI::~StoreUI()
{
}

void Sigmodr::StoreUI::refreshGui()
{
    varItems->clear();
    for (int i = 0; i < sigmod()->itemCount(); ++i)
    {
        const Sigmod::Item* item = sigmod()->item(i);
        QListWidgetItem* widgetItem = new QListWidgetItem(item->name(), varItems);
        widgetItem->setData(Qt::UserRole, item->id());
    }
}

void Sigmodr::StoreUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Store*>(modified())->name());
    for (int i = 0; i < varItems->count(); ++i)
    {
        QListWidgetItem* widgetItem = varItems->item(i);
        widgetItem->setSelected(qobject_cast<Sigmod::Store*>(modified())->item(widgetItem->data(Qt::UserRole).toInt()));
    }
}

void Sigmodr::StoreUI::apply()
{
    *qobject_cast<Sigmod::Store*>(original()) = *qobject_cast<Sigmod::Store*>(modified());
    emit(changed(false));
}

void Sigmodr::StoreUI::discard()
{
    *qobject_cast<Sigmod::Store*>(modified()) = *qobject_cast<Sigmod::Store*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::StoreUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Store*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::StoreUI::on_varItems_itemClicked(QListWidgetItem* item)
{
    qobject_cast<Sigmod::Store*>(modified())->setItem(item->data(Qt::UserRole).toInt(), item->isSelected());
}
