/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "TileUI.h"

// Sigmod includes
#include "../sigmod/Tile.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Sprite.h"

Sigmodr::TileUI::TileUI(Sigmod::Tile* tile, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(tile, new Sigmod::Tile(*tile));
}

Sigmodr::TileUI::~TileUI()
{
}

void Sigmodr::TileUI::initGui()
{
    QListWidgetItem* item;
    item = new QListWidgetItem(Sigmod::DirectionStr[Sigmod::D_Up], varAccessibility);
    item->setData(Qt::UserRole, QVariant::fromValue(Sigmod::D_Up));
    item = new QListWidgetItem(Sigmod::DirectionStr[Sigmod::D_Down], varAccessibility);
    item->setData(Qt::UserRole, QVariant::fromValue(Sigmod::D_Down));
    item = new QListWidgetItem(Sigmod::DirectionStr[Sigmod::D_Left], varAccessibility);
    item->setData(Qt::UserRole, QVariant::fromValue(Sigmod::D_Left));
    item = new QListWidgetItem(Sigmod::DirectionStr[Sigmod::D_Right], varAccessibility);
    item->setData(Qt::UserRole, QVariant::fromValue(Sigmod::D_Right));
}

void Sigmodr::TileUI::refreshGui()
{
    for (int i = 0; i < sigmod()->spriteCount(); ++i)
    {
        const Sigmod::Sprite* sprite = sigmod()->sprite(i);
        if (sprite->sprite().size() == QSize(64, 64))
            varSprite->addItem(QPixmap::fromImage(sprite->sprite()), sprite->name(), sprite->id());
    }
}

void Sigmodr::TileUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Tile*>(modified())->name());
    varSprite->setCurrentIndex(varSprite->findData(qobject_cast<Sigmod::Tile*>(modified())->sprite()));
    for (int i = 0; i < varAccessibility->count(); ++i)
        varAccessibility->item(i)->setSelected(qobject_cast<Sigmod::Tile*>(modified())->from(QVariant(i).value<Sigmod::Direction>()));
    varScript->setValue(qobject_cast<Sigmod::Tile*>(modified())->script());
}

void Sigmodr::TileUI::apply()
{
    *qobject_cast<Sigmod::Tile*>(original()) = *qobject_cast<Sigmod::Tile*>(modified());
    emit(changed(false));
}

void Sigmodr::TileUI::discard()
{
    *qobject_cast<Sigmod::Tile*>(modified()) = *qobject_cast<Sigmod::Tile*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::TileUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Tile*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::TileUI::on_varSprite_currentIndexChanged(const int sprite)
{
    qobject_cast<Sigmod::Tile*>(modified())->setSprite(varSprite->itemData(sprite).toInt());
}

void Sigmodr::TileUI::on_varAccessibility_itemClicked(QListWidgetItem* item)
{
    qobject_cast<Sigmod::Tile*>(modified())->setFrom(item->data(Qt::UserRole).value<Sigmod::Direction>(), item->isSelected());
}

void Sigmodr::TileUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::Tile*>(modified())->setScript(script);
}
