/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "TypeUI.h"

// Sigmod includes
#include "../sigmod/Type.h"

Sigmodr::TypeUI::TypeUI(Sigmod::Type* type, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(type, new Sigmod::Type(*type));
}

Sigmodr::TypeUI::~TypeUI()
{
}

void Sigmodr::TypeUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Type*>(modified())->name());
    varSTAB->setValue(qobject_cast<Sigmod::Type*>(modified())->stab());
}

void Sigmodr::TypeUI::apply()
{
    *qobject_cast<Sigmod::Type*>(original()) = *qobject_cast<Sigmod::Type*>(modified());
    emit(changed(false));
}

void Sigmodr::TypeUI::discard()
{
    *qobject_cast<Sigmod::Type*>(modified()) = *qobject_cast<Sigmod::Type*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::TypeUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Type*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::TypeUI::on_varSTAB_valueChanged(const Sigmod::Fraction& stab)
{
    qobject_cast<Sigmod::Type*>(modified())->setStab(stab);
}
