/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "WeatherUI.h"

// Sigmod includes
#include "../sigmod/Weather.h"

Sigmodr::WeatherUI::WeatherUI(Sigmod::Weather* weather, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(weather, new Sigmod::Weather(*weather));
}

Sigmodr::WeatherUI::~WeatherUI()
{
}

void Sigmodr::WeatherUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Weather*>(modified())->name());
    varScript->setValue(qobject_cast<Sigmod::Weather*>(modified())->script());
}

void Sigmodr::WeatherUI::apply()
{
    *qobject_cast<Sigmod::Weather*>(original()) = *qobject_cast<Sigmod::Weather*>(modified());
    emit(changed(false));
}

void Sigmodr::WeatherUI::discard()
{
    *qobject_cast<Sigmod::Weather*>(modified()) = *qobject_cast<Sigmod::Weather*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::WeatherUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Weather*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::WeatherUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::Weather*>(modified())->setScript(script);
}
