/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "CoinListObjectModel.h"

// Model includes
#include "GroupObjectModel.h"

// Sigmodr includes
#include "../CoinListObjectUI.h"

// Sigmod includes
#include "../../sigmod/CoinList.h"
#include "../../sigmod/CoinListObject.h"
#include "../../sigmod/Item.h"
#include "../../sigmod/Sigmod.h"
#include "../../sigmod/Species.h"

// KDE includes
#include <KMenu>

Sigmodr::CoinListObjectModel::CoinListObjectModel(BaseModel* parent, Sigmod::CoinListObject* object) :
        ObjectModel(parent, object)
{
}

Sigmodr::CoinListObjectModel::~CoinListObjectModel()
{
}

QVariant Sigmodr::CoinListObjectModel::data(int role) const
{
    if (role == Qt::DisplayRole)
    {
        Sigmod::CoinListObject* object = qobject_cast<Sigmod::CoinListObject*>(m_object);
        if (object->type() == Sigmod::CoinListObject::Item)
        {
            const int index = qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->itemIndex(object->object());
            if (index != INT_MAX)
                return qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->item(index)->name();
        }
        else if (object->type() == Sigmod::CoinListObject::Species)
        {
            const int index = qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->speciesIndex(object->object());
            if (index != INT_MAX)
                return qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->species(index)->name();
        }
        return "";
    }
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new CoinListObjectUI(qobject_cast<Sigmod::CoinListObject*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Object", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::ObjectModel::data(role);
}

void Sigmodr::CoinListObjectModel::deleteSelf()
{
    qobject_cast<GroupObjectModel*>(m_parent)->deleteObject(this);
}
