/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWarpGroupModel.h"

// Model includes
#include "MapWarpModel.h"

// Map includes
#include "../../sigmod/Map.h"
#include "../../sigmod/MapWarp.h"

// KDE includes
#include <KMenu>

Sigmodr::MapWarpGroupModel::MapWarpGroupModel(BaseModel* parent, Sigmod::Map* map) :
        GroupModel(parent, map, "Warps")
{
    for (int i = 0; i < map->warpCount(); ++i)
        addObject(map->warp(i));
}

Sigmodr::MapWarpGroupModel::~MapWarpGroupModel()
{
}

QVariant Sigmodr::MapWarpGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Warp", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::MapWarpGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "MapWarp"))
            {
                addObject(qobject_cast<Sigmod::Map*>(m_object)->newWarp(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::MapWarpGroupModel::types() const
{
    return "MapWarp";
}

void Sigmodr::MapWarpGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Map*>(m_object)->newWarp();
    if (object->className() == "MapWarp")
        addChild(new MapWarpModel(this, qobject_cast<Sigmod::MapWarp*>(object)));
}

void Sigmodr::MapWarpGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Map*>(m_object)->deleteWarp(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
