/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListEncounterModel.h"

// Model includes
#include "GroupObjectModel.h"

// Sigmodr includes
#include "../MapWildListEncounterUI.h"

// Sigmod includes
#include "../../sigmod/MapWildList.h"
#include "../../sigmod/MapWildListEncounter.h"
#include "../../sigmod/Sigmod.h"
#include "../../sigmod/Species.h"

// KDE includes
#include <KMenu>

Sigmodr::MapWildListEncounterModel::MapWildListEncounterModel(BaseModel* parent, Sigmod::MapWildListEncounter* encounter) :
        ObjectModel(parent, encounter)
{
}

Sigmodr::MapWildListEncounterModel::~MapWildListEncounterModel()
{
}

QVariant Sigmodr::MapWildListEncounterModel::data(int role) const
{
    if (role == Qt::DisplayRole)
    {
        const Sigmod::Species* species = qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->speciesById(qobject_cast<Sigmod::MapWildListEncounter*>(m_object)->species());
        if (species)
            return species->name();
        return "";
    }
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new MapWildListEncounterUI(qobject_cast<Sigmod::MapWildListEncounter*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Encounter", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::ObjectModel::data(role);
}

void Sigmodr::MapWildListEncounterModel::deleteSelf()
{
    qobject_cast<GroupObjectModel*>(m_parent)->deleteObject(this);
}
