/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListGroupModel.h"

// Model includes
#include "MapWildListModel.h"

// Map includes
#include "../../sigmod/Map.h"
#include "../../sigmod/MapWildList.h"

// KDE includes
#include <KMenu>

Sigmodr::MapWildListGroupModel::MapWildListGroupModel(BaseModel* parent, Sigmod::Map* map) :
        GroupModel(parent, map, "Wild Lists")
{
    for (int i = 0; i < map->wildListCount(); ++i)
        addObject(map->wildList(i));
}

Sigmodr::MapWildListGroupModel::~MapWildListGroupModel()
{
}

QVariant Sigmodr::MapWildListGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Wild List", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::MapWildListGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "MapWildList"))
            {
                addObject(qobject_cast<Sigmod::Map*>(m_object)->newWildList(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::MapWildListGroupModel::types() const
{
    return "MapWildList";
}

void Sigmodr::MapWildListGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Map*>(m_object)->newWildList();
    if (object->className() == "MapWildList")
        addChild(new MapWildListModel(this, qobject_cast<Sigmod::MapWildList*>(object)));
}

void Sigmodr::MapWildListGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Map*>(m_object)->deleteWildList(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
