/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListModel.h"

// Model includes
#include "MapWildListEncounterModel.h"
#include "GroupModel.h"

// Sigmodr includes
#include "../MapWildListUI.h"

// Sigmod includes
#include "../../sigmod/Map.h"
#include "../../sigmod/MapWildList.h"
#include "../../sigmod/MapWildListEncounter.h"

// KDE includes
#include <KMenu>

Sigmodr::MapWildListModel::MapWildListModel(BaseModel* parent, Sigmod::MapWildList* wildList) :
        GroupObjectModel(parent, wildList)
{
    setupData();
}

Sigmodr::MapWildListModel::~MapWildListModel()
{
    clearData();
}

QVariant Sigmodr::MapWildListModel::data(int role) const
{
    if (role == Qt::DisplayRole)
    {
        return qobject_cast<Sigmod::MapWildList*>(m_object)->name();
    }
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new MapWildListUI(qobject_cast<Sigmod::MapWildList*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Encounter", this, SLOT(addObject()));
        menu->addSeparator();
        menu->addAction("&Delete Wild List", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupObjectModel::data(role);
}
bool Sigmodr::MapWildListModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml))
            {
                if (xml.doctype().name() == m_object->className())
                {
                    clearData();
                    m_object->load(xml.documentElement());
                    setupData();
                    return true;
                }
                else if (xml.doctype().name() == "MapWildListEncounter")
                {
                    addObject(qobject_cast<Sigmod::MapWildList*>(m_object)->newEncounter(xml.documentElement()));
                    return true;
                }
            }
        }
    }
    return false;
}

QString Sigmodr::MapWildListModel::types() const
{
    return type().append(";MapWildListEncounter");
}

void Sigmodr::MapWildListModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::MapWildList*>(m_object)->newEncounter();
    if (object->className() == "MapWildListEncounter")
        addChild(new MapWildListEncounterModel(this, qobject_cast<Sigmod::MapWildListEncounter*>(object)));
}

void Sigmodr::MapWildListModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::MapWildList*>(m_object)->deleteEncounter(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}

void Sigmodr::MapWildListModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}

void Sigmodr::MapWildListModel::setupData()
{
    Sigmod::MapWildList* wildList = qobject_cast<Sigmod::MapWildList*>(m_object);
    for (int i = 0; i < wildList->encounterCount(); ++i)
        addChild(new MapWildListEncounterModel(this, wildList->encounter(i)));
}
