/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ObjectModel.h"

// Sigmod includes
#include "../../sigmod/Object.h"

// Qt includes
#include <QtXml/QDomDocument>

Sigmodr::ObjectModel::ObjectModel(BaseModel* parent, Sigmod::Object* object) :
        BaseObjectModel(parent, object)
{
}

Sigmodr::ObjectModel::~ObjectModel()
{
}

int Sigmodr::ObjectModel::rowCount() const
{
    return 0;
}

QVariant Sigmodr::ObjectModel::data(int role) const
{
    return Sigmodr::BaseObjectModel::data(role);
}

bool Sigmodr::ObjectModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == m_object->className()))
            {
                m_object->load(xml.documentElement());
                return true;
            }
        }
    }
    return false;
}

Sigmodr::BaseModel* Sigmodr::ObjectModel::childItem(const int /*row*/)
{
    return NULL;
}

QString Sigmodr::ObjectModel::types() const
{
    return type();
}
