/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesModel.h"

// Model includes
#include "SpeciesAbilityGroupModel.h"
#include "SpeciesItemGroupModel.h"
#include "SpeciesMoveGroupModel.h"

// Sigmodr includes
#include "../SpeciesUI.h"

// Sigmod includes
#include "../../sigmod/Sigmod.h"
#include "../../sigmod/Species.h"

// KDE includes
#include <KMenu>

Sigmodr::SpeciesModel::SpeciesModel(BaseModel* parent, Sigmod::Species* species) :
        GroupObjectModel(parent, species)
{
    setupData();
}

Sigmodr::SpeciesModel::~SpeciesModel()
{
    clearData();
}

QVariant Sigmodr::SpeciesModel::data(int role) const
{
    if (role == Qt::DisplayRole)
        return qobject_cast<Sigmod::Species*>(m_object)->name();
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new SpeciesUI(qobject_cast<Sigmod::Species*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Species", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupObjectModel::data(role);
}

bool Sigmodr::SpeciesModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml))
            {
                if (xml.doctype().name() == m_object->className())
                {
                    clearData();
                    m_object->load(xml.documentElement());
                    setupData();
                    return true;
                }
                foreach (BaseModel* model, m_objects)
                {
                    GroupModel* group = qobject_cast<GroupModel*>(model);
                    if (group && group->setData(value, role))
                        return true;
                }
            }
        }
    }
    return false;
}

QString Sigmodr::SpeciesModel::types() const
{
    return type().append(";SpeciesAbility;SpeciesItem;SpeciesMove");
}

void Sigmodr::SpeciesModel::addObject(Sigmod::Object* /*object*/)
{
}

void Sigmodr::SpeciesModel::deleteObject(BaseModel* /*model*/)
{
}

void Sigmodr::SpeciesModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}

void Sigmodr::SpeciesModel::setupData()
{
    Sigmod::Species* species = qobject_cast<Sigmod::Species*>(m_object);
    addChild(new SpeciesAbilityGroupModel(this, species));
    addChild(new SpeciesItemGroupModel(this, species));
    addChild(new SpeciesMoveGroupModel(this, species));
}
