/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesMoveGroupModel.h"

// Model includes
#include "SpeciesMoveModel.h"

// Sigmod includes
#include "../../sigmod/Species.h"
#include "../../sigmod/SpeciesMove.h"

// KDE includes
#include <KMenu>

Sigmodr::SpeciesMoveGroupModel::SpeciesMoveGroupModel(BaseModel* parent, Sigmod::Species* species) :
        GroupModel(parent, species, "Moves")
{
    for (int i = 0; i < species->moveCount(); ++i)
        addObject(species->move(i));
}

Sigmodr::SpeciesMoveGroupModel::~SpeciesMoveGroupModel()
{
}

QVariant Sigmodr::SpeciesMoveGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Move", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::SpeciesMoveGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "SpeciesMove"))
            {
                addObject(qobject_cast<Sigmod::Species*>(m_object)->newMove(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::SpeciesMoveGroupModel::types() const
{
    return "SpeciesMove";
}

void Sigmodr::SpeciesMoveGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Species*>(m_object)->newMove();
    if (object->className() == "SpeciesMove")
        addChild(new SpeciesMoveModel(this, qobject_cast<Sigmod::SpeciesMove*>(object)));
}

void Sigmodr::SpeciesMoveGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Species*>(m_object)->deleteMove(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
