/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "StoreGroupModel.h"

// Model includes
#include "StoreModel.h"

// Sigmod includes
#include "../../sigmod/Sigmod.h"
#include "../../sigmod/Store.h"

// KDE includes
#include <KMenu>

Sigmodr::StoreGroupModel::StoreGroupModel(BaseModel* parent, Sigmod::Sigmod* sigmod) :
        GroupModel(parent, sigmod, "Stores")
{
    for (int i = 0; i < sigmod->storeCount(); ++i)
        addObject(sigmod->store(i));
}

Sigmodr::StoreGroupModel::~StoreGroupModel()
{
}

QVariant Sigmodr::StoreGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Store", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::StoreGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "Store"))
            {
                addObject(qobject_cast<Sigmod::Sigmod*>(m_object)->newStore(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::StoreGroupModel::types() const
{
    return "Store";
}

void Sigmodr::StoreGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Sigmod*>(m_object)->newStore();
    if (object->className() == "Store")
        addChild(new StoreModel(this, qobject_cast<Sigmod::Store*>(object)));
}

void Sigmodr::StoreGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Sigmod*>(m_object)->deleteStore(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
