/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "TypeModel.h"

// Model includes
#include "GroupModel.h"

// Sigmodr includes
#include "../TypeUI.h"

// Sigmod includes
#include "../../sigmod/Sigmod.h"
#include "../../sigmod/Type.h"

// KDE includes
#include <KMenu>

Sigmodr::TypeModel::TypeModel(BaseModel* parent, Sigmod::Type* type) :
        ObjectModel(parent, type)
{
}

Sigmodr::TypeModel::~TypeModel()
{
}

QVariant Sigmodr::TypeModel::data(int role) const
{
    if (role == Qt::DisplayRole)
        return qobject_cast<Sigmod::Type*>(m_object)->name();
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new TypeUI(qobject_cast<Sigmod::Type*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Type", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::ObjectModel::data(role);
}

void Sigmodr::TypeModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}
