/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGSCRIPT_CONFIG
#define SIGSCRIPT_CONFIG

// Sigscript includes
#include "Global.h"

// Qt includes
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QObject>
#include <QtCore/QString>
#include <QtCore/QVariant>

// Forward declarations
namespace Sigmod
{
class Sigmod;
}

namespace Sigscript
{
class SIGSCRIPT_EXPORT Config : public QObject
{
    Q_OBJECT
    
    public:
        Config(QObject* parent);
        
        Q_SCRIPTABLE QVariant value(const QString& name, const bool recursive = true) const;
        template<typename T> T valueOfType(const QString& name, const bool recursive = false) const;
        Q_SCRIPTABLE bool hasValue(const QString& name, const bool recursive = false) const;
        template<typename T> bool hasValueOfType(const QString& name, const bool recursive = false) const;
    signals:
        void valueAdded(const QString& name, const QVariant& value);
        void valueChanged(const QString& name, const QVariant& oldValue, const QVariant& newValue);
        void valueRemoved(const QString& name);
    public slots:
        void addValue(const QString& name, const QVariant& value, const bool temporary = false);
        void setValue(const QString& name, const QVariant& value, const bool temporary = false);
        void removeValue(const QString& name);
        
        void clearTemporary();
        
        virtual void writeBack();
    private:
        QMap<QString, QVariant> m_values;
        QList<QString> m_temporaries;
};

template<typename T> T Config::valueOfType(const QString& name, const bool recursive) const
{
    if (hasValueOfType<T>(name))
        return m_values[name].value<T>();
    if (recursive)
    {
        QObject* par = parent();
        while (par)
        {
            if (qobject_cast<Config*>(par) && qobject_cast<Config*>(par)->hasValue(name))
                return qobject_cast<Config*>(par)->valueOfType<T>(name);
            par = par->parent();
        }
    }
    return T();
}

template<typename T> bool Config::hasValueOfType(const QString& name, const bool recursive) const
{
    if (m_values.contains(name) && m_values[name].canConvert<T>())
        return true;
    if (recursive && qobject_cast<Config*>(parent()))
        return qobject_cast<Config*>(parent())->hasValueOfType<T>(name, true);
    return false;
}

}
Q_DECLARE_METATYPE(Sigscript::Config*)

#endif
