/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ItemTypeWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::ItemTypeWrapper* Sigscript::ItemTypeWrapper::create(const Sigmod::ItemType* itemType, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, itemType->id())))
        m_instances[Signature(parent, itemType->id())] = new ItemTypeWrapper(itemType, parent);
    return qobject_cast<ItemTypeWrapper*>(m_instances[Signature(parent, itemType->id())]);
}

Sigscript::ItemTypeWrapper::ItemTypeWrapper(const Sigmod::ItemType* itemType, SigmodWrapper* parent) :
        ObjectWrapper(itemType, parent),
        m_itemType(itemType)
{
}

Sigmod::ItemType::Count Sigscript::ItemTypeWrapper::count(const QString& name) const
{
    if (name == "Distinct")
        return Sigmod::ItemType::Distinct;
    else if (name == "Total")
        return Sigmod::ItemType::Total;
    return QVariant(-1).value<Sigmod::ItemType::Count>();
}

QString Sigscript::ItemTypeWrapper::name() const
{
    return m_itemType->name();
}

int Sigscript::ItemTypeWrapper::computer() const
{
    return m_itemType->computer();
}

int Sigscript::ItemTypeWrapper::player() const
{
    return m_itemType->player();
}

int Sigscript::ItemTypeWrapper::count() const
{
    return m_itemType->count();
}
