/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ItemWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::ItemWrapper* Sigscript::ItemWrapper::create(const Sigmod::Item* item, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, item->id())))
        m_instances[Signature(parent, item->id())] = new ItemWrapper(item, parent);
    return qobject_cast<ItemWrapper*>(m_instances[Signature(parent, item->id())]);
}

Sigscript::ItemWrapper::ItemWrapper(const Sigmod::Item* item, SigmodWrapper* parent) :
        ObjectWrapper(item, parent),
        m_item(item)
{
}

QString Sigscript::ItemWrapper::name() const
{
    return m_item->name();
}

bool Sigscript::ItemWrapper::sellable() const
{
    return m_item->sellable();
}

Sigscript::ItemTypeWrapper* Sigscript::ItemWrapper::type()
{
    return sigmod()->itemType(m_item->type());
}

int Sigscript::ItemWrapper::price() const
{
    if (hasValueOfType<int>("price"))
        return valueOfType<int>("price");
    return m_item->price();
}

QString Sigscript::ItemWrapper::description() const
{
    return m_item->description();
}

Sigmod::Script Sigscript::ItemWrapper::script() const
{
    return m_item->script();
}
