/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWarpWrapper.h"

// Sigscript includes
#include "MapWrapper.h"
#include "SigmodWrapper.h"

Sigscript::MapWarpWrapper* Sigscript::MapWarpWrapper::create(const Sigmod::MapWarp* warp, MapWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, warp->id())))
        m_instances[Signature(parent, warp->id())] = new MapWarpWrapper(warp, parent);
    return qobject_cast<MapWarpWrapper*>(m_instances[Signature(parent, warp->id())]);
}

Sigscript::MapWarpWrapper::MapWarpWrapper(const Sigmod::MapWarp* warp, MapWrapper* parent) :
        ObjectWrapper(warp, parent),
        m_warp(warp)
{
}

Sigmod::MapWarp::Type Sigscript::MapWarpWrapper::type(const QString& name) const
{
    if (name == "Door")
        return Sigmod::MapWarp::Door;
    else if (name == "Warp")
        return Sigmod::MapWarp::Warp;
    else if (name == "Hole")
        return Sigmod::MapWarp::Hole;
    else if (name == "Boundary")
        return Sigmod::MapWarp::Boundary;
    return QVariant(-1).value<Sigmod::MapWarp::Type>();
}

QString Sigscript::MapWarpWrapper::name() const
{
    return m_warp->name();
}

QPoint Sigscript::MapWarpWrapper::coordinate() const
{
    if (hasValueOfType<QPoint>("coordinate"))
        return valueOfType<QPoint>("coordinate");
    return m_warp->coordinate();
}

Sigmod::MapWarp::Type Sigscript::MapWarpWrapper::type() const
{
    return m_warp->type();
}

Sigscript::MapWarpWrapper* Sigscript::MapWarpWrapper::toWarp()
{
    return sigmod()->map(m_warp->toMap())->warp(m_warp->toWarp());
}

Sigmod::Script Sigscript::MapWarpWrapper::script() const
{
    return m_warp->script();
}
