/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ObjectWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

QMap<Sigscript::ObjectWrapper::Signature, Sigscript::ObjectWrapper*> Sigscript::ObjectWrapper::m_instances;

Sigscript::ObjectWrapper::ObjectWrapper(const Sigmod::Object* object, ObjectWrapper* parent) :
        Config(parent),
        m_object(object)
{
}

int Sigscript::ObjectWrapper::id() const
{
    return m_object->id();
}

const Sigscript::ObjectWrapper* Sigscript::ObjectWrapper::parent() const
{
    return m_parent;
}

Sigscript::ObjectWrapper* Sigscript::ObjectWrapper::parent()
{
    return m_parent;
}

const Sigscript::SigmodWrapper* Sigscript::ObjectWrapper::sigmod() const
{
    if (m_parent)
        return m_parent->sigmod();
    return qobject_cast<const SigmodWrapper*>(m_parent);
}

Sigscript::SigmodWrapper* Sigscript::ObjectWrapper::sigmod()
{
    if (m_parent)
        return m_parent->sigmod();
    return qobject_cast<SigmodWrapper*>(m_parent);
}
