/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "StoreWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::StoreWrapper* Sigscript::StoreWrapper::create(const Sigmod::Store* store, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, store->id())))
        m_instances[Signature(parent, store->id())] = new StoreWrapper(store, parent);
    return qobject_cast<StoreWrapper*>(m_instances[Signature(parent, store->id())]);
}

Sigscript::StoreWrapper::StoreWrapper(const Sigmod::Store* store, SigmodWrapper* parent) :
        ObjectWrapper(store, parent),
        m_store(store)
{
}

QString Sigscript::StoreWrapper::name() const
{
    return m_store->name();
}

QList<Sigscript::ItemWrapper*> Sigscript::StoreWrapper::items()
{
    QList<int> itemIds = m_store->items();
    QList<ItemWrapper*> items;
    foreach (int id, itemIds)
        items.append(sigmod()->item(id));
    return items;
}
